Coverage for tictactoe/tools/testing: 83%

# Coverage for tictactoe/tools/testing : 83%

## 6 statements 5 run 1 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 | from django.test import override_settings def sync_celery(function=None): """Synchronous task execution by celery. Does not require redis""" actual_decorator = override_settings( CELERY_EAGER_PROPAGATES_EXCEPTIONS=True, CELERY_ALWAYS_EAGER=True, BROKER_BACKEND='memory' ) if function: return actual_decorator(function) return actual_decorator